@@ -9,6 +9,7 @@
 #include <QProcess>
 #include <stdio.h>
 #include <string.h>
+#include <QDialog>
 
 #include <stdlib.h>
 #include <alsa/asoundlib.h>
@@ -41,14 +42,20 @@ public slots:
   QString getAlsaSample();
   QString getAlsaVersion(); // libasound
   bool isbusy();            // libasound
+  void busyDialog( QString AlsaHw, QString AlsaName );
+  QString getPurAlsaName();
   void setChannel();
 
+private:  
+  QDialog *newDialog;
   
 private slots:
   void setCard( QString string );
   void setAlsaHw();
   void setAlsaName();
   void setAlsaSample();
+  void closeDialog();
+  QString getUsedBy();
 
   
   //void alsa_device_sample( const char *device_name, unsigned int rate );
@@ -65,7 +72,7 @@ private:
   QString AlsaCannel;
   QString AlsaName;
   QString AlsaSample;
-  
+  QString alsaName;
 };
 
 #endif
