@@ -19,7 +19,14 @@
     </message>
     <message>
         <source>Used by</source>
-        <translation>مستخدمة من طرف</translation>
+        <translation>مستخدمة بواسطة</translation>
+    </message>
+</context>
+<context>
+    <name>Dialog</name>
+    <message>
+        <source>Show Click Settings</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -59,6 +66,13 @@
         <translation>اختر ملفاً أو أكثر</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise</name>
+    <message>
+        <source>double-click to maximize</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>QvkWebcamWindow</name>
     <message>
@@ -98,7 +112,7 @@
     </message>
     <message>
         <source>Used by</source>
-        <translation>مستخدمة من طرف</translation>
+        <translation>مستخدمة بواسطة</translation>
     </message>
     <message>
         <source>Unknown</source>
@@ -108,7 +122,7 @@
 <context>
     <name>regionselection</name>
     <message>
-        <source>doubleclick extended to the edge</source>
+        <source>double-click to maximize</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -254,10 +268,6 @@
         <source>Donate</source>
         <translation>تبرع</translation>
     </message>
-    <message>
-        <source>Program for recording</source>
-        <translation>برنامج التسجيل</translation>
-    </message>
     <message>
         <source>Translations</source>
         <translation>الترجمات</translation>
@@ -296,7 +306,7 @@
     </message>
     <message>
         <source>Display</source>
-        <translation>الشاشة</translation>
+        <translation>العرض</translation>
     </message>
     <message>
         <source>All Displays</source>
@@ -306,5 +316,29 @@
         <source>Developer Homepage</source>
         <translation>صفحة المطوّر</translation>
     </message>
+    <message>
+        <source>Recorder</source>
+        <translation>المسجّل</translation>
+    </message>
+    <message>
+        <source>Select recorder</source>
+        <translation>اختر المسجّل</translation>
+    </message>
+    <message>
+        <source>Hide window</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Exit</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Show window</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Lossless</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 </TS>
\ No newline at end of file
