@@ -22,6 +22,13 @@
         <translation>W użyciu przez</translation>
     </message>
 </context>
+<context>
+    <name>Dialog</name>
+    <message>
+        <source>Show Click Settings</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>MailDialog</name>
     <message>
@@ -59,6 +66,13 @@
         <translation>Wybierz jeden lub wiele plików</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise</name>
+    <message>
+        <source>double-click to maximize</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>QvkWebcamWindow</name>
     <message>
@@ -71,15 +85,15 @@
     </message>
     <message>
         <source>Show over fullscreen</source>
-        <translation>Pokarz nad pełnym ekranem</translation>
+        <translation>Pokaż nad pełnym ekranem</translation>
     </message>
     <message>
         <source>Right click for menu</source>
-        <translation type="unfinished"/>
+        <translation>Prawy przycisk otwiera menu</translation>
     </message>
     <message>
         <source>User-defined</source>
-        <translation type="unfinished"/>
+        <translation>Zdefiniowany przez użytkownika</translation>
     </message>
 </context>
 <context>
@@ -108,7 +122,7 @@
 <context>
     <name>regionselection</name>
     <message>
-        <source>doubleclick extended to the edge</source>
+        <source>double-click to maximize</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -156,7 +170,7 @@
     </message>
     <message>
         <source>Videopath</source>
-        <translation>Ścieżka wideo</translation>
+        <translation>Zapisz nagranie w</translation>
     </message>
     <message>
         <source>Player</source>
@@ -204,7 +218,7 @@
     </message>
     <message>
         <source>Settings fps</source>
-        <translation>Ustawiona liczba klatek</translation>
+        <translation>Żądany klatkaż</translation>
     </message>
     <message>
         <source>Open Directory</source>
@@ -228,7 +242,7 @@
     </message>
     <message>
         <source>Actual frames per second</source>
-        <translation>Aktualna liczba klatek na sekundę</translation>
+        <translation>Rzeczywisty klatkaż</translation>
     </message>
     <message>
         <source>Go</source>
@@ -254,10 +268,6 @@
         <source>Donate</source>
         <translation>Darowizna</translation>
     </message>
-    <message>
-        <source>Program for recording</source>
-        <translation>Program nagrywający</translation>
-    </message>
     <message>
         <source>Translations</source>
         <translation>Tłumaczenia</translation>
@@ -268,7 +278,7 @@
     </message>
     <message>
         <source>Show in systray</source>
-        <translation>Pokazuj w tacce systemowej</translation>
+        <translation>Pokazuj w panelu systemowym</translation>
     </message>
     <message>
         <source>New version available</source>
@@ -306,5 +316,29 @@
         <source>Developer Homepage</source>
         <translation>Strona programisty</translation>
     </message>
+    <message>
+        <source>Recorder</source>
+        <translation>Rejestrator</translation>
+    </message>
+    <message>
+        <source>Select recorder</source>
+        <translation>Wybierz rejestrator</translation>
+    </message>
+    <message>
+        <source>Hide window</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Exit</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Show window</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Lossless</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 </TS>
\ No newline at end of file
