@@ -22,6 +22,13 @@
         <translation type="unfinished"/>
     </message>
 </context>
+<context>
+    <name>Dialog</name>
+    <message>
+        <source>Show Click Settings</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>MailDialog</name>
     <message>
@@ -59,6 +66,13 @@
         <translation>Виберіть один або кілька файлів</translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise</name>
+    <message>
+        <source>double-click to maximize</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>QvkWebcamWindow</name>
     <message>
@@ -108,7 +122,7 @@
 <context>
     <name>regionselection</name>
     <message>
-        <source>doubleclick extended to the edge</source>
+        <source>double-click to maximize</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -254,10 +268,6 @@
         <source>Donate</source>
         <translation>Зробити внесок</translation>
     </message>
-    <message>
-        <source>Program for recording</source>
-        <translation>Програма для запису</translation>
-    </message>
     <message>
         <source>Translations</source>
         <translation>Переклади</translation>
@@ -306,5 +316,29 @@
         <source>Developer Homepage</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Recorder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Select recorder</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Hide window</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Exit</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Show window</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Lossless</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 </TS>
\ No newline at end of file
