@@ -24,6 +24,13 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>Dialog</name>
+    <message>
+        <source>Show Click Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>MailDialog</name>
     <message>
@@ -61,6 +68,13 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>QvkRegionChoise</name>
+    <message>
+        <source>double-click to maximize</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QvkWebcamWindow</name>
     <message>
@@ -325,7 +339,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Showkey</source>
+        <source>Lossless</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
