@@ -18,7 +18,7 @@ Q_OBJECT
 public:
   QvkMail();
   virtual ~QvkMail();
-  QvkMail( QWidget *object );
+  QvkMail( QString value );
 
 
 public slots:
@@ -42,12 +42,10 @@ protected:
   
 private:
   QDialog *newDialog;
-//  QDialog * dialog;
-//  QRadioButton * mailRadioButton;
-//  QRadioButton * mailSelectedRadioButton;
-  
   Ui_MailDialog myUiMailDialog;
-
+  QString videoPath;
+  
+  
 };
 
 #endif
