@@ -4,6 +4,7 @@
 #include <QObject>
 #include <QSettings>
 #include <QDebug>
+#include <QColor>
 
 class QvkSettings: public QObject
 { 
@@ -33,6 +34,7 @@ public:
   // Miscellaneous
   QString getVideoPath();
   QString getVideoPlayer();
+  QString getGIFPlayer();
   int getMinimized();
   int getCountdown();
   QString getRecorder();
@@ -40,6 +42,7 @@ public:
   // Videooptions
   int getFrames();
   QString getVideoCodec();
+  int getX264Lossless();
   QString getAudioCodec();
   QString getVideoContainer();
   int getHideMouse();
@@ -62,16 +65,32 @@ public:
   int getWebcamY();
   int getWebcamHeight();
   int getWebcamWidth();
-  bool getWebcamMirrored();
+  int getWebcamMirrored();
   bool getWebcamBorder();
   bool getWebcamOverFullScreen();
-  
+  bool getWebcamButtonTopMiddle();
+  bool getWebcamButtonRightMiddle();
+  bool getWebcamButtonBottomMiddle();
+  bool getWebcamButtonLeftMiddle();
+
   // Magnifier
   int getMagnifierOnOff();
   int getMagnifierFormValue();
+  
+  // ShowClick
+  int    getShowClickOnOff();
+  int    getShowClickCircle();
+  bool   getShowClickRadiant();
+  QColor getShowClickColor();
+  double getShowClickOpacity();
+  double getShowClickTime();
 
+  // ShowKey
+  int getShowKeyOnOff();
+  
+  
 public slots:
-
+  bool isVokoscreenWithLibs();
   
 private slots:
 
@@ -92,17 +111,23 @@ private:
   bool FullScreenSelect;
   bool WindowSelect;
   bool AreaSelect;
+  int Countdown;
+  
   QString VideoPath;
   QString VideoPlayer;
+  QString GIFPlayer;
   int Minimized;
-  int Countdown;
+  
   int Frames;
   QString VideoCodec;
+  int x264Lossless;
   QString AudioCodec;
   QString VideoContainer;
   int HideMouse;
   QString Recorder;
   
+  bool vokoscreenWithLibs;
+  
   // Gui
   int X;
   int Y;
@@ -121,13 +146,29 @@ private:
   int webcamY;
   int webcamHeight;
   int webcamWidth;
-  bool webcamMirrored;
+  int webcamMirrored;
   bool webcamBorder;
   bool webcamOverFullScreen;
+  bool webcamButtonTopMiddle;
+  bool webcamButtonRightMiddle;
+  bool webcamButtonBottomMiddle;
+  bool webcamButtonLeftMiddle;
   
   // Magnifier
   int magnifierOnOff;
   int magnifierFormValue;
+  
+  // ShowClick
+  int showClickOnOff;
+  int showClickCircle;
+  bool showClickRadiant;
+  QColor showClickColor;
+  double showClickOpacity;
+  double showClickTime;
+  
+  // ShowKey
+  int showKeyOnOff;
+  
 };
 
 #endif
