@@ -30,12 +30,12 @@ public:
   virtual ~QvkWebcamController();
   
   QStringList webcamList;
-  QvkWidgetcircle *mirrorWidget;
  
+  QvkWebcamWindow *webcamWindow;
+  
   
 public slots:
   void webcamCloseEvent();
-  void saveSettings();
 
   
 private slots:
@@ -50,13 +50,11 @@ private slots:
   
   void readWebcams( QStringList );
   void webcams();
-
-  void enterEventWebcamWindow();
-  void leaveEventWebcamWindow();
-  void resizeEventWebcamWindow();
+  void checkBox_OnOff();
 
   
 private:
+  QvkSettings vkSettings;
   QFrame *rotateFrame;
   QCheckBox *checkBox;
   QComboBox *comboBox;
@@ -68,10 +66,8 @@ private:
   QRadioButton *radioButtonLeftMiddle;
   QvkWebcamWatcher * myWebcamWatcher;
   CaptureThread *captureThread;
-  QvkWebcamWindow *webcamWindow;
   bool mirrored;
 
-  QvkSettings vkSettings;
 
 protected:
   
