@@ -11,12 +11,10 @@ QvkWebcamWindow::QvkWebcamWindow()
   setWindowTitle( "vokoscreen webcam");
   setToolTip( tr( "Right click for menu" ) );
 
-  //if( QX11Info::isCompositingManagerRunning() ) // QT5 *************************** vorerst Ersatzlos gestrichen ******************************************************
-    setAttribute( Qt::WA_TranslucentBackground, true );
+  setAttribute( Qt::WA_TranslucentBackground, true );
   
   webcamLabel = new QLabel( this );
   webcamLabel->setAlignment( Qt::AlignCenter );
-  webcamLabel->setScaledContents( true );
   webcamLabel->show();
  
   action160x120 = new QAction( "160 x 120", this );
@@ -41,8 +39,7 @@ QvkWebcamWindow::QvkWebcamWindow()
 
   actionVisibleOverFullscreen = new QAction( tr ( "Show over fullscreen" ), this );
   actionVisibleOverFullscreen->setCheckable( true );
-  //actionVisibleOverFullscreen->setChecked( false );
-  connect( actionVisibleOverFullscreen, SIGNAL( triggered() ), this, SLOT( setVisibleOverFullscreen() ) );
+  connect( actionVisibleOverFullscreen, SIGNAL( triggered() ), this, SLOT( setVisibleOverFullscreen_New() ) );
 
   actionClose = new QAction( tr ( "Close" ), this );
   connect( actionClose, SIGNAL( triggered() ), this, SLOT( closeMenue() ) );
@@ -84,10 +81,10 @@ QvkWebcamWindow::QvkWebcamWindow()
     setOverFullScreen( true );
     setVisibleOverFullscreen();
   }
-  else // ************** Neu
+  else
   {
-    actionVisibleOverFullscreen->setChecked( false ); //************************ Neu
-    setOverFullScreen( false ); //******* Neu
+    actionVisibleOverFullscreen->setChecked( false );
+    setOverFullScreen( false );
   }
 }
 
@@ -95,6 +92,12 @@ QvkWebcamWindow::~QvkWebcamWindow()
 {
 }
 
+void QvkWebcamWindow::setVisibleOverFullscreen_New()
+{
+  emit setOverScreen();
+}
+
+
 void QvkWebcamWindow::setValueBorder( bool value )
 {
   border = value; 
@@ -173,6 +176,9 @@ void QvkWebcamWindow::closeMenue()
  
 void QvkWebcamWindow::set160x120()
 {
+  if ( isMaximized() )
+    showNormal();
+
   setGeometry( geometry().x(), geometry().y(), 160, 120 );
   action160x120->setChecked( true );
   action320x240->setChecked( false );
@@ -184,6 +190,9 @@ void QvkWebcamWindow::set160x120()
 
 void QvkWebcamWindow::set320x240()
 {
+  if ( isMaximized() )
+    showNormal();
+
   setGeometry( geometry().x(), geometry().y(), 320, 240 );
   action160x120->setChecked( false );
   action320x240->setChecked( true );
@@ -195,6 +204,9 @@ void QvkWebcamWindow::set320x240()
 
 void QvkWebcamWindow::set640x480()
 {
+  if ( isMaximized() )
+    showNormal();
+  
   setGeometry( geometry().x(), geometry().y(), 640, 480 );
   action160x120->setChecked( false );
   action320x240->setChecked( false );
@@ -238,7 +250,7 @@ void QvkWebcamWindow::setVisibleOverFullscreen()
 {
   if ( actionVisibleOverFullscreen->isChecked() )
   {
-    setWindowFlags( Qt::WindowTitleHint | Qt::WindowStaysOnTopHint | Qt::X11BypassWindowManagerHint );
+    setWindowFlags( Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint | Qt::X11BypassWindowManagerHint );
     actionBorder->setChecked( false );
     setOverFullScreen( true );
     setValueBorder( false );
@@ -250,7 +262,7 @@ void QvkWebcamWindow::setVisibleOverFullscreen()
     setWindowFlags( Qt::WindowTitleHint | Qt::WindowStaysOnTopHint );
     actionBorder->setChecked( true );
     setOverFullScreen( false );
-    setValueBorder( true ); //******************************************** Neu
+    setValueBorder( true );
     activateWindow();
     show();
   }
@@ -259,8 +271,6 @@ void QvkWebcamWindow::setVisibleOverFullscreen()
 
 void QvkWebcamWindow::resizeEvent ( QResizeEvent *)
 {
-  emit resizeEventWebcamWindow();
-
   webcamLabel->setGeometry( 0, 0, width(), height() );
 
   if ( ( width() == 160 ) and ( height() == 120 ) )
@@ -280,14 +290,3 @@ void QvkWebcamWindow::resizeEvent ( QResizeEvent *)
               setActionUserDefined();
             }
 }
-
-
-void QvkWebcamWindow::enterEvent( QEvent* )
-{
-  emit enterEventWebcamWindow();
-}
-   
-void QvkWebcamWindow::leaveEvent( QEvent* )
-{
-  emit leaveEventWebcamWindow();
-}   
