@@ -10,7 +10,6 @@
 #include <QDebug>
 
 #include "QvkSettings.h"
-#include "QvkWidgetcircle.h"
 
 class QvkWebcamWindow : public QMainWindow
 {
@@ -21,18 +20,12 @@ public:
     virtual ~QvkWebcamWindow();
     QString currentDevice;
     QLabel *webcamLabel;
-    bool getValueBorder();
-    int getValueX();
-    int getValueY();
-    int getValueWidth();
-    int getValueHeight();
-    bool getOverFullScreen();
 
     QAction *action160x120;
     QAction *action320x240;
     QAction *action640x480;
     QAction *actionUserDefined;
-    QAction * actionBorder;
+    QAction *actionBorder;
     QAction *actionVisibleOverFullscreen;
     QAction *actionClose;
     QMenu menu;
@@ -44,6 +37,13 @@ private:
     QvkSettings vkSettings;
     
 public slots:
+    int getValueX();
+    int getValueY();
+    int getValueWidth();
+    int getValueHeight();
+    bool getOverFullScreen();
+    bool getValueBorder();
+    void setVisibleOverFullscreen();
 
     
 private slots:
@@ -52,23 +52,21 @@ private slots:
     void set640x480();
     void setActionUserDefined();
     void setBorder();
-    void setVisibleOverFullscreen();
     void closeMenue();
     void setValueBorder( bool value );
     void setOverFullScreen( bool value );
+    
+    void setVisibleOverFullscreen_New();
 
 protected:
     void closeEvent( QCloseEvent * event );
     void contextMenuEvent( QContextMenuEvent *event );
     void resizeEvent ( QResizeEvent * );
-    void enterEvent( QEvent* );
-    void leaveEvent( QEvent* );
     
 signals:
     void closeWebcamWindow();
     void enterEventWebcamWindow();
-    void leaveEventWebcamWindow();
-    void resizeEventWebcamWindow();
+    void setOverScreen();
 };
 
 #endif
